import Vue from 'vue'
import 'normalize.css/normalize.css' // A modern alternative to CSS resets
import moment from 'moment'
// import ElementUI from 'element-ui'
// import './styles/element-variables.scss'
// import locale from 'element-ui/lib/locale/lang/en' // lang i18n
import './plugins'
import xhr from '@/utils/request'
import '@/styles/index.scss' // global css
import halberd from '@/utils/halberd'
import App from './App'
import store from './store'
import router from './router'
import permission from './directive/permission'
// import drective from '@/utils/directive.js'
import '@/icons' // icon
import '@/assets/icons' // icon
import '@/permission' // permission control
import './utils/rem.js' // 自适应分辨率

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online ! ! !
 */
// const { mockXHR } = require('../mock')
// mockXHR()
import { includePermission } from '@/utils/common'
import { getDicts } from '@/api/system/dict/data'
import { getConfigKey } from '@/api/system/config'
import { parseTime, resetForm, addDateRange, selectDictLabel, download, handleTree, addDateRangeMothon, addDateLoginMothon } from '@/utils/common'
import Pagination from '@/components/Pagination'
import { uploadPublic } from '@/api/fileUploadPublic'
import Viewer from 'v-viewer'
import 'viewerjs/dist/viewer.css'
Vue.use(Viewer)
Viewer.setDefaults({
  Options: {
    'inline': true, 'button': true, 'navbar': false, 'title': true,
    'toolbar': true, 'tooltip': true, 'movable': true, 'zoomable': true,
    'rotatable': true, 'scalable': true, 'transition': true, 'fullscreen': false,
    'keyboard': true, minZoomRatio: 0.50, maxZoomRatio: 150
  }
})

// 全局方法挂载
Vue.prototype.getDicts = getDicts
Vue.prototype.getConfigKey = getConfigKey
Vue.prototype.parseTime = parseTime
Vue.prototype.resetForm = resetForm
Vue.prototype.addDateRange = addDateRange
Vue.prototype.addDateRangeMothon = addDateRangeMothon
Vue.prototype.addDateLoginMothon = addDateLoginMothon
Vue.prototype.selectDictLabel = selectDictLabel
Vue.prototype.download = download
Vue.prototype.handleTree = handleTree
Vue.prototype.UIUrl = process.env.VUE_APP_UI
Vue.prototype.$ha = halberd
Vue.prototype.$uploadFile = uploadPublic
Vue.prototype.$haveAuth = includePermission
// set ElementUI lang to EN
Vue.prototype.$axios = xhr

// 未解析的函数或方法 msgSuccess()，需添加以下代码
Vue.prototype.msgSuccess = function(msg) {
  this.$message({ showClose: true, message: msg, type: 'success' })
}

Vue.prototype.$parseDate = (value, format) => {
  if (!value || value === '') {
    return '-'
  }
  return moment(value).format(format || 'YYYY-MM-DD HH:mm:ss')
}
// 如果想要中文版 element-ui，按如下方式声明
// Vue.use(ElementUI)
// Vue.use(drective)
Vue.config.productionTip = false
// 全局组件挂载
Vue.component('Pagination', Pagination)

Vue.use(permission)

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})

// 全局日期转换过滤器 传格式/默认为YYYY-MM-DD HH:mm
Vue.filter('transformDateByFormat', (value, format) => {
  if (!value || value === '') {
    return '-'
  }
  return moment(value).format(format || 'YYYY-MM-DD HH:mm:ss')
})
